import Config from './config';
export interface IPlurals {
    one?: string;
    few?: string;
    many?: string;
    other?: string;
}
/**
 * Check data type.
 * @param  maybeStrings - Maybe array of strings.
 * @return Given data is array of strings.
 */
export declare function isStringsArray(maybeStrings: any): maybeStrings is TemplateStringsArray | string[];
/**
 * Handling of template literals.
 * @param  text - Text or text parts.
 * @return Processed text.
 */
export declare function preProcess<T>(text: T | TemplateStringsArray | string[]): T | string;
/**
 * Handling of templates.
 * @param  text - Text to process.
 * @param  namedValues - Named values for mustache.
 * @param  values - List of values for vsprintf.
 * @param  count - Plural param.
 * @return Processed text.
 */
export declare function postProcess(config: Config, text: string, namedValues: any, values: any[], count?: number): string;
/**
 * Get singular from plurals object.
 * @param  plurals - Plurals object to get sigular form.
 * @return Singular.
 */
export declare function getSingularFromPlurals(plurals: IPlurals): string;
/**
 * Parse float from string, if `num` is `string`.
 * @param  num - Number or string to handle.
 * @return Maybe number and number is or not.
 */
export declare function tryParseFloat(num: string | number): [number, boolean];
/**
 * Core translate function.
 * @param  config - Config object.
 * @param  locale - Target locale.
 * @param  singular - Singular form.
 * @param  plural - Plural form.
 * @return Translation.
 */
export declare function translate(config: Config, locale: string, singular: string, plural?: string): string | IPlurals;
//# sourceMappingURL=core.d.ts.map