import Config, { IConfig, ILocales, IFallbacks, IUnknownPhraseListener, IProcessor } from './config';
export { pluralIntervalProcessor, mustacheProcessor } from './processors';
export interface IParams {
    phrase: string;
    locale?: string;
}
export interface IPluralParams {
    singular: string;
    plural?: string;
    count?: number | string;
    locale?: string;
}
export declare type I18nConfig = Config;
declare const globalConfig: Config;
export { globalConfig as default, IConfig, ILocales, IFallbacks, IUnknownPhraseListener, IProcessor };
/**
 * Translates a single phrase and adds it to locales if unknown.
 * @param  phraseOrParams - Phrase to translate or params.
 * @param  values - Values to print.
 * @return Returns translated parsed and substituted string.
 */
export declare function __(phraseOrParams: string | TemplateStringsArray | IParams, ...values: any[]): string;
/**
 * Supports the advanced MessageFormat as provided by excellent messageformat module.
 * You should definetly head over to messageformat.github.io for a guide to MessageFormat.
 * `i18n-for-browser` takes care of `new MessageFormat('en').compile(msg);`
 * with the current msg loaded from it's json files and cache that complied fn in memory.
 * So in short you might use it similar to `__()` plus extra object to accomblish MessageFormat's formating.
 * @param  phraseOrParams - Phrase to translate or params.
 * @param  values - Values to print.
 * @return Translate.
 */
export declare function __mf(phraseOrParams: string | TemplateStringsArray | IParams, ...values: any[]): string;
/**
 * Plurals translation of a single phrase.
 * Singular and plural forms will get added to locales if unknown.
 * Returns translated parsed and substituted string based on `count` parameter.
 * @param  params - Translate params.
 * @param  count - Target count.
 * @param  values - Values to print.
 * @return Translate.
 */
export declare function __n(params: IPluralParams, count?: string | number, ...values: any[]): string;
/**
 * Plurals translation of a single phrase.
 * Singular and plural forms will get added to locales if unknown.
 * Returns translated parsed and substituted string based on `count` parameter.
 * @param  singularOrStrings - Singular form to translate, or array of strings.
 * @param  count - Target count.
 * @param  values - Values to print.
 * @return Translate.
 */
export declare function __n(singularOrStrings: string | TemplateStringsArray, count: string | number, ...values: any[]): string;
/**
 * Plurals translation of a single phrase.
 * Singular and plural forms will get added to locales if unknown.
 * Returns translated parsed and substituted string based on `count` parameter.
 * @param  singular - Singular form to translate.
 * @param  plural - Plural form to translate.
 * @param  count - Target count.
 * @param  values - Values to print.
 * @return Translate.
 */
export declare function __n(singular: string, plural: string, count: string | number, ...values: any[]): string;
/**
 * Returns a map of translations for a given phrase in each language.
 * @param  phrase - Phrase to translate.
 * @return Map of translations.
 */
export declare function __m(phrase: string): ILocales;
//# sourceMappingURL=index.d.ts.map